import 'dart:convert';

import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter_plugin_kyc/flutter_plugin_kyc.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  String _kycResult = "";

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    // We also handle the message potentially returning null.
    try {
      platformVersion =
          await FlutterPluginKyc.platformVersion ?? 'Unknown platform version';
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }
  setKycResult(result){
    Map valueMap = json.decode(result);
    if((valueMap['backImage']??"").length > 20){
      valueMap['backImage'] = valueMap['backImage'].substring(1,15)+"...";
    }
    if((valueMap['frontImage']??"").length > 20){
      valueMap['frontImage'] = valueMap['frontImage'].substring(1,15)+"...";
    }
    if((valueMap['livePhoto']??"").length > 20){
      valueMap['livePhoto'] = valueMap['livePhoto'].substring(1,15)+"...";
    }
    result = json.encode(valueMap);
    setState(() {
      if(result.length > 5000){
        result = result.substring(0,5000);
      }
      _kycResult = result;
    });

  }
  trulioKYC() async {
    String result = '';
    try {
      result = await FlutterPluginKyc.kyc ?? "";
      setKycResult(result);
    } on Exception catch (e) {
      result = e.toString();
    }

  }
  selfi() async {
    String result = '';
    try {
      result = await FlutterPluginKyc.selfi ?? "";
      setKycResult(result);
    } on Exception catch (e) {
      result = e.toString();
    }

  }
  front() async {
    String result = '';
    try {
      result = await FlutterPluginKyc.front ?? "";
      setKycResult(result);
    } on Exception catch (e) {
      result = e.toString();
    }

  }
  back() async {
    String result = '';
    try {
      result = await FlutterPluginKyc.back ?? "";
      setKycResult(result);
    } on Exception catch (e) {
      result = e.toString();
    }

  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Column(
            children: [
              Text('Running on: $_platformVersion\n'),
              ElevatedButton(onPressed: trulioKYC, child: Text('KYC')),
              ElevatedButton(onPressed: front, child: Text('Front')),
              ElevatedButton(onPressed: back, child: Text('Back')),
              ElevatedButton(onPressed: selfi, child: Text('Selfi')),
              Expanded(child: SingleChildScrollView(child:Text(_kycResult)))
            ],
          ),
        ),
      ),
    );
  }
}
